{% load sekizai_tags staticfiles %}

{% addtoblock "css" %}
<link rel="stylesheet" href="{% static 'leprikon/lib/bootstrap-datetimepicker.min.css' %}"/>
{% endaddtoblock %}

{% addtoblock "js" %}
<script src="{% static 'leprikon/lib/moment-with-locales.min.js' %}"></script>
{% endaddtoblock %}

{% addtoblock "js" %}
<script src="{% static 'leprikon/lib/bootstrap-datetimepicker.min.js' %}"></script>
{% endaddtoblock %}

{% addtoblock "js" %}
<script type="text/javascript">
$(function () {
    $('input[data-type=DateField]').datetimepicker({
        locale: '{{ LANGUAGE_CODE }}',
        format: 'L',
    });
    $('input[data-type=TimeField]').datetimepicker({
        locale: '{{ LANGUAGE_CODE }}',
        format: 'LT',
    });
});
</script>
{% endaddtoblock %}
