{% extends 'leprikon/base.html' %}
{% load i18n cms_tags leprikon_tags %}

{% block content %}

<h1>{% block title %}{% blocktrans with school_year=request.school_year %}Registrations in school year {{ school_year }}{% endblocktrans %}{% endblock %}</h1>

{% static_placeholder "registrations" %}

{% if courseregistrations.count or eventregistrations.count %}
{% for reg in courseregistrations %}{% include 'leprikon/registration_preview.html' %}{% endfor %}
{% for reg in eventregistrations %}{% include 'leprikon/registration_preview.html' %}{% endfor %}
{% else %}
<p>{% blocktrans with school_year=request.school_year %}You have no registrations in school year {{ school_year }}.{% endblocktrans %}</p>
{% endif %}

{% endblock %}
